@@ -359,8 +359,7 @@ class ResultsView(gobject.GObject, search.SearchConsumer):
                 self.__added_headings.add(heading)
 
             icon = r.get_icon()
-            icon_is_url = False
-            if icon and icon.startswith(os.sep):
+            if icon and isinstance(icon, basestring) and icon.startswith(os.sep):
                 icon = gtk.gdk.pixbuf_new_from_file_at_size(icon, _ICON_SIZE, _ICON_SIZE)
             icon_url = r.get_icon_url()
 
